#!/bin/sh
#
#   Copyright (c) 2009 by IBM Corporation.
#
# ##############################################################################
# Please don't hesitate to contact IBM Rational Software Support if you have any 
# questions or encountered any difficulties with this script.
# ##############################################################################
#
# This script provide support to install the integration between IBM Rational Tau 
# and IBM Rational Synergy on Unix.
# -----------------------------------------------------------------------------
#
#set -x
PATH=.:/bin:/usr/bin:/usr/ucb
export PATH

# Default-values
ECHO='echo'

case `uname -mr` in
  5*sun4*  	      )	hosttype=sunos5
	                HOSTTYPE=SUNOS5
			username=`/usr/ucb/whoami`
			ECHO='echo' ;;
  2*86*  	      )	hosttype=linux
	                HOSTTYPE=LINUX
			username=`/usr/bin/whoami`
			ECHO='echo -e' ;;

esac

check_textansw()
{
  case $1 in
    x | X ) exit 0 ;;
    "" ) tauinstdir=$TAU ;;
  esac
}


# Check the selected installation directory
check_installation_dir()
{
    # Check if specified path is a directory
    if [ ! -d "$tauinstdir" ]; then
	$ECHO ""
	$ECHO ">>      Directory $tauinstdir doesn't exist."
	$ECHO ">>      Exiting Installation without completion...."
	exit 0
    fi
    if [ ! -w "$tauinstdir" ]; then
	$ECHO ""
	$ECHO ">>      Directory $tauinstdir isn't writeable."
	$ECHO ">>      Exiting Installation without completion...."
	exit 0
    fi
    if [ ! -d "$tauinstdir/tools/cm_integrations" ]; then
	$ECHO ""
	$ECHO ">>      Directory $tauinstdir doesn't seem to be a IBM Rational Tau installation directory."
	$ECHO ">>      Exiting Installation without completion...."
	exit 0
    fi
}

# Ask for installation directory
ask_where_to_install()
{

  $ECHO ""
  $ECHO "        Installation Procedure Tau Integration with Synergy."
  $ECHO ""
  $ECHO "        Specify the existing directory path for your IBM Rational Tau installation"
  $ECHO ">>      Enter path-name ($TAU): \c"
  read tauinstdir
  check_textansw $tauinstdir
  export tauinstdir
}

# Ask for synergy installation directory
ask_where_synergy_is()
{

  $ECHO "        Specify the existing directory path for your IBM Rational Synergy installation"
  $ECHO ">>      Enter path-name ($CCM_HOME): \c"
  read syninstdir
  export syninstdir
}

install_untar()
{
    TARCOM="tar xf"
    tardir=$PWD
    cd $tauinstdir
    $TARCOM $tardir/tausynergy.tar 
}

#update regfile
#first replace TAU_DIR with actual tau installation path
#second replace SYNCM_DIR with actual synergy installation path
update_regfile()
{
    sed "s@\[TAU_DIR\]@$tauinstdir@g" $tauinstdir/tools/cm_integrations/tausyn_template.reg >$tauinstdir/tools/cm_integrations/temp.reg
    sed "s@\[SYNCM_DIR\]@$syninstdir@g" $tauinstdir/tools/cm_integrations/temp.reg >$tauinstdir/tools/cm_integrations/tausyn.reg
    chmod a+r $tauinstdir/tools/cm_integrations/tausyn.reg
    $ECHO "Synergy integration registry file successfully patched."
}

# -------------------------  START of install procedure -----------------------

cd `dirname $0`

ask_where_to_install

ask_where_synergy_is

check_installation_dir

install_untar

update_regfile

exit 0
